==> hs-gio-0.12.3p1.tgz: lib/ghc/gio-0.12.3/register.sh <==
#!/bin/sh
echo 'name: gio
version: 0.12.3
id: gio-0.12.3-f342b5f4ffd40d3a7b464b22b3f89f5f

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the GIO.
description: GIO is striving to provide a modern, easy-to-use VFS API that sits at the right level in the library stack.
             The goal is to overcome the shortcomings of GnomeVFS and provide an API that is
             so good that developers prefer it over raw POSIX calls.
             Among other things that means using GObject.
             It also means not cloning the POSIX API, but providing higher-level, document-centric interfaces.
category: System
author: Peter Gavin, Andy Stewart
pkgpath: devel/hs-gio
exposed: True
exposed-modules: System.GIO System.GIO.Enums System.GIO.Types
                 System.GIO.Async.AsyncResult System.GIO.Async.Cancellable
                 System.GIO.File.AppInfo System.GIO.File.ContentType
                 System.GIO.File.FileAttribute System.GIO.File.File
                 System.GIO.File.FileEnumerator System.GIO.File.FileInfo
                 System.GIO.File.FileMonitor System.GIO.File.IOError
                 System.GIO.File.MountOperation System.GIO.Icons.Emblem
                 System.GIO.Icons.EmblemedIcon System.GIO.Icons.FileIcon
                 System.GIO.Icons.Icon System.GIO.Icons.ThemedIcon
                 System.GIO.Volumes.Drive System.GIO.Volumes.Mount
                 System.GIO.Volumes.Volume System.GIO.Volumes.VolumeMonitor
hidden-modules: System.GIO.Signals
trusted: False
import-dirs: /usr/local/lib/ghc/gio-0.12.3
library-dirs: /usr/local/lib/ghc/gio-0.12.3 /usr/local/lib
hs-libraries: HSgio-0.12.3
extra-libraries: gio-2.0 gobject-2.0 glib-2.0 intl iconv
extra-ghci-libraries:
include-dirs: /usr/local/include/glib-2.0
              /usr/local/lib/glib-2.0/include /usr/local/include
includes:
depends: array-0.4.0.0-4f6c2a594155b0b953c1cf0f54040f61
         base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
         glib-0.12.3.1-802d98cfe9a88c3ac80f8e30d4b86d4a
         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-gio-0.12.3/html/gio.haddock
haddock-html: /usr/local/share/doc/hs-gio-0.12.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-gio-0.12.4.tgz: lib/ghc/gio-0.12.4/register.sh <==
#!/bin/sh
echo 'name: gio
version: 0.12.4
id: gio-0.12.4-a17738b9fa63112ce05f51d740ccb9ab

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the GIO.
description: GIO is striving to provide a modern, easy-to-use VFS API that sits at the right level in the library stack.
             The goal is to overcome the shortcomings of GnomeVFS and provide an API that is
             so good that developers prefer it over raw POSIX calls.
             Among other things that means using GObject.
             It also means not cloning the POSIX API, but providing higher-level, document-centric interfaces.
category: System
author: Peter Gavin, Andy Stewart
pkgpath: devel/hs-gio
exposed: True
exposed-modules: System.GIO System.GIO.Enums System.GIO.Types
                 System.GIO.Async.AsyncResult System.GIO.Async.Cancellable
                 System.GIO.File.AppInfo System.GIO.File.ContentType
                 System.GIO.File.FileAttribute System.GIO.File.File
                 System.GIO.File.FileEnumerator System.GIO.File.FileInfo
                 System.GIO.File.FileMonitor System.GIO.File.IOError
                 System.GIO.File.MountOperation System.GIO.Icons.Emblem
                 System.GIO.Icons.EmblemedIcon System.GIO.Icons.FileIcon
                 System.GIO.Icons.Icon System.GIO.Icons.ThemedIcon
                 System.GIO.Volumes.Drive System.GIO.Volumes.Mount
                 System.GIO.Volumes.Volume System.GIO.Volumes.VolumeMonitor
hidden-modules: System.GIO.Signals
trusted: False
import-dirs: /usr/local/lib/ghc/gio-0.12.4
library-dirs: /usr/local/lib/ghc/gio-0.12.4 /usr/local/lib
hs-libraries: HSgio-0.12.4
extra-libraries: gio-2.0 gobject-2.0 glib-2.0 intl
extra-ghci-libraries:
include-dirs: /usr/local/include/glib-2.0
              /usr/local/lib/glib-2.0/include /usr/local/include
includes:
depends: array-0.4.0.1-3b78425c10ff2dad7acf7e8c8ae014c3
         base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
         glib-0.12.4-e3c24025d434894ff47dcfccf269abe4
         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-gio-0.12.4/html/gio.haddock
haddock-html: /usr/local/share/doc/hs-gio-0.12.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
